AudioContent class

Audio content part for speech-capable models.

Constructors

AudioContent({required String data, required String format})
const

Properties

data String
Base64-encoded audio data.
final
format String
Audio format (e.g., "wav", "mp3", "ogg").
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override