AuthType enum

Auth scheme used by a provider.

Inheritance
Available extensions

Values

bearer → const AuthType

Standard Authorization: Bearer <key> header.

apiKey → const AuthType

x-api-key: <key> header (also handles "header" and "x-api-key" aliases).

none → const AuthType

No authentication header required.

unknown → const AuthType

Unrecognised auth scheme — falls back to bearer.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthType>
A constant List of the values in this enum, in order of their declaration.