CacheConfig class
Configuration for the response cache.
Constructors
- CacheConfig({required PlatformInt64 maxEntries, required PlatformInt64 ttl, required CacheBackend backend})
-
const
Properties
- backend → CacheBackend
-
Storage backend to use.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxEntries → int
-
Maximum number of cached entries.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ttl → int
-
Time-to-live for each cached entry.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override