DeveloperMessage class

Developer message (system-like message for Claude models).

Constructors

DeveloperMessage({required String content, String? name})
const

Properties

content String
Developer-specific instructions or context.
final
hashCode int
The hash code for this object.
no setteroverride
name String?
Optional name for the developer message source.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override