CreateResponseRequest class
Request to create a structured response.
Constructors
-
CreateResponseRequest({required String model, required String input, String? instructions, List<
ResponseTool> ? tools, double? temperature, PlatformInt64? maxOutputTokens, String? metadata}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- input → String
-
Input data to process (e.g., a document to extract from).
final
- instructions → String?
-
Instructions for processing the input.
final
- maxOutputTokens → PlatformInt64?
-
Maximum output tokens.
final
- metadata → String?
-
Optional metadata.
final
- model → String
-
Model ID.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temperature → double?
-
Sampling temperature in
[0.0, 2.0]. Defaults to 1.0.final -
tools
→ List<
ResponseTool> ? -
Available tools the model can use.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override