OcrImage class
An image extracted from an OCR page.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
Unique image identifier within the document.
final
- imageBase64 → String?
-
Base64-encoded image data (if
include_image_base64was true).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override